@@ -1,9 +1,12 @@
+# frozen_string_literal: true
 module Maxitest
   module Pending
-    def pending(reason=nil, **kwargs)
+    def pending(reason = nil, **kwargs)
       raise ArgumentError, "Need a block to execute" unless block_given?
-      raise ArgumentError, "Only :if option is supported" if (kwargs.keys | [:if] != [:if])
-      return yield if kwargs.fetch(:if, true) == false # allow user to for example mark test only pending on CI with `if: ENV["CI"]`
+      raise ArgumentError, "Only :if option is supported" if (kwargs.keys | [:if]) != [:if]
+
+      # allow user to for example mark test only pending on CI with `if: ENV["CI"]`
+      return yield if kwargs.fetch(:if, true) == false
 
       begin
         yield # execute test
@@ -16,4 +19,4 @@ module Maxitest
   end
 end
 
-Minitest::Test.send(:include, Maxitest::Pending)
+Minitest::Test.include Maxitest::Pending
