@@ -1,7 +1,6 @@
+# frozen_string_literal: true
 # tests that leave extra threads running can break other tests in weird ways ... prevent that from happening
 
-raise "Upgrade above minitest 5.0 to use this feature" if Minitest::VERSION.start_with?("5.0")
-
 module Maxitest
   module Threads
     def setup
@@ -36,4 +35,4 @@ end
 
 # not using prepend since that would clash with webmock
 # include works because original setup lives in also included Minitest::LifecycleHooks
-Minitest::Test.send :include, Maxitest::Threads
+Minitest::Test.include Maxitest::Threads
