@@ -1,4 +1,4 @@
-ENV["GLOBAL_MUST"] = "true"
+# frozen_string_literal: true
 require "./spec/cases/helper"
 
 describe 2 do
