@@ -1,4 +1,8 @@
-ENV["GLOBAL_MUST"] = "true"
+# frozen_string_literal: true
+if ENV['GLOBAL_MUST']
+  require 'maxitest/global_must'
+end
+
 require "./spec/cases/helper"
 
 describe "threads" do
@@ -10,14 +14,16 @@ describe "threads" do
     assert_it
   end
 
+  it "fails" do
+    ENV["FAIL"].must_be_nil
+  end
+
   it "can assert in threads" do
     result = "not called"
     Thread.new do
-      begin
-        assert_it
-      rescue NoMethodError, RuntimeError, NameError # different errors depending on minitest and ruby version
-        result = "error"
-      end
+      assert_it
+    rescue NotImplementedError
+      result = "error"
     end.join
     result.must_equal "error"
   end
