@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require 'bundler/setup'
 $VERBOSE = true
 
@@ -7,8 +8,4 @@ if ENV['SIMULATE_TTY']
   end
 end
 
-if ENV['GLOBAL_MUST']
-  require 'maxitest/global_must'
-end
-
 require 'maxitest/autorun'
