@@ -1,7 +1,8 @@
+# frozen_string_literal: true
 require "./spec/cases/helper"
 
 describe 3 do
   it "is even" do
-    2.even?.must_equal true
+    _(2.even?).must_equal true
   end
 end
