@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require "./spec/cases/helper"
 
 $ordered_calls = []
@@ -22,6 +23,6 @@ describe 2 do
   end
 
   it "z" do
-    $ordered_calls.must_equal [1,2,3,4]
+    _($ordered_calls).must_equal [1, 2, 3, 4]
   end
 end
