@@ -1,10 +1,11 @@
+# frozen_string_literal: true
 require "./spec/cases/helper"
 Maxitest.static_class_order = true
 $calls = []
 
 5.times do |i|
   describe rand do
-    it { puts "#{i}" }
+    it { puts i }
 
     describe rand do
       it { puts "#{i}n" }
