@@ -1,5 +1,5 @@
+# frozen_string_literal: true
 require "maxitest/version"
-require "maxitest"
 require "minitest"
 
 RSpec.configure do |config|
